@@ -160,6 +160,29 @@ class SurfingEntrance(object):
 
         self.check_fund_list(yesterday, wechat_bot)
 
+    def calc_fund_estimated_nav(self):
+        import datetime
+        from .data.fund.raw.raw_data_helper import RawDataHelper
+        from .data.api.raw import RawDataApi
+        from .util.config import SurfingConfigurator
+        from .data.fund.raw.rq_raw_data_downloader import RqRawDataDownloader
+
+        time_start = datetime.datetime.now()
+        rq_license = SurfingConfigurator().get_license_settings('rq')
+        rq_raw_data_downloader = RqRawDataDownloader(rq_license, RawDataHelper())
+        stock_minute_df = rq_raw_data_downloader.stock_minute()
+        # print(f'stock_minute_df\n {stock_minute_df}')
+        if stock_minute_df is None or stock_minute_df.empty:
+            # TODO: send alert if failed
+            return False
+
+        from .data.fund.basic.basic_data_helper import BasicDataHelper
+        from .data.fund.basic.basic_data_part3_estimated_nav import BasicDataPart3
+        basic_data_processor = BasicDataPart3(BasicDataHelper())
+        basic_data_processor.calc_fund_estimated_nav(stock_minute_df)
+        time_end = datetime.datetime.now()
+        print(f'Time for calc_fund_estimated_nav is {(time_end - time_start).total_seconds()} seconds')
+
     def check_fund_list(self, yesterday=None, wechat_bot=None):
         from .data.fund.raw.raw_data_helper import RawDataHelper
         from .data.api.raw import RawDataApi
