@@ -145,15 +145,20 @@ class BasicDataApi(object):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {StockInfo.__tablename__}')
 
-    def get_fund_nav(self, fund_list):
+    def get_fund_nav(self, fund_list=None, dt=None):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
                         FundNav
-                ).filter(
-                        # We could query all fund_ids at one time
+                )
+                if fund_list:
+                    query = query.filter(
                         FundNav.fund_id.in_(fund_list),
                     )
+                if dt:
+                    query = query.filter(
+                        FundNav.datetime == dt,
+                    )
 
                 tag_df = pd.read_sql(query.statement, query.session.bind)
                 return tag_df
@@ -509,14 +514,21 @@ class BasicDataApi(object):
                 print(f'Failed to get time range data <err_msg> {e} from {FundHoldIndustry.__tablename__}')
                 return
 
-    def get_fund_hold_stock(self, dt) -> pd.DataFrame:
-       with BasicDatabaseConnector().managed_session() as db_session:
+    def get_fund_hold_stock(self, dt=None) -> pd.DataFrame:
+        with BasicDatabaseConnector().managed_session() as db_session:
             try:
+                if not dt:
+                    dt = db_session.query(
+                        func.max(FundHoldStock.datetime)
+                    ).one_or_none()
+                    if dt:
+                        dt = dt[0]
+                    
                 query = db_session.query(
-                        FundHoldStock
-                        ).filter(
-                            FundHoldStock.datetime == dt
-                        )
+                    FundHoldStock
+                ).filter(
+                    FundHoldStock.datetime == dt
+                )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get time range data <err_msg> {e} from {FundHoldStock.__tablename__}')
