@@ -2,6 +2,7 @@ from typing import List, Tuple
 import pandas as pd
 from ..wrapper.mysql import RawDatabaseConnector
 from ..view.raw_models import *
+from sqlalchemy.sql import func
 
 
 class RawDataApi:
@@ -318,6 +319,26 @@ class RawDataApi:
                 print('Failed to get data <err_msg> {}'.format(e))
                 return None
 
+    def get_rq_stock_minute(self, dt=None):
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                if not dt:
+                    dt = db_session.query(
+                        func.max(RqStockMinute.datetime)
+                    ).one_or_none()
+                if dt:
+                    dt = dt[0]
+                query = db_session.query(
+                    RqStockMinute
+                ).filter(
+                    RqStockMinute.datetime == dt
+                )
+                df = pd.read_sql(query.statement, query.session.bind)
+                return df
+            except Exception as e:
+                print('Failed to get data <err_msg> {}'.format(e))
+                return None
+                
     def get_em_index_price(self, start_date, end_date, index_id_list: Tuple = ()):
         with RawDatabaseConnector().managed_session() as db_session:
             try:
