@@ -33,7 +33,8 @@ class BasicFundRet(BasicDataPart1):
         self.end_date = end_date if isinstance(end_date, datetime.date) else datetime.datetime.strptime(end_date,'%Y%m%d').date()
         self.fund_list = self._fund_info_df.fund_id.tolist()
         self.fund_nav = self.basic_api.get_fund_nav_with_date(self.start_date, self.end_date, self.fund_list)
-        self.fund_scale = self.raw_api.get_em_fund_scale(self.start_date, self.end_date)
+        # 直接使用basic的最新fund scale
+        self.fund_scale = self.basic_api.get_fund_size()
         self.index_list = list(set(self._fund_info_df.index_id))
         self._fund_to_enddate_dict = self._fund_info_df[['fund_id', 'end_date']].set_index('fund_id').to_dict()['end_date']
         self.fund_nav = self.fund_nav.pivot_table(index='datetime', columns='fund_id', values='adjusted_net_value').fillna(method='ffill')
@@ -43,11 +44,8 @@ class BasicFundRet(BasicDataPart1):
             fund_end_date = self._fund_to_enddate_dict[fund_id]
             if self.end_date > fund_end_date:
                 self.fund_nav.loc[fund_end_date:,fund_id] = np.nan
-        # 基金规模数据表更新fund_id
-        self.fund_scale['fund_id'] = self.fund_scale.apply(
-            lambda x: self._data_helper._get_fund_id_from_order_book_id(x['CODES'].split('.')[0], x['DATES']), axis=1)
-        self.fund_scale = self.fund_scale.rename(columns={'DATES':'datetime'})[['datetime','FUNDSCALE','fund_id']].pivot_table(index='datetime',values='FUNDSCALE',columns='fund_id')
-        self.fund_scale = self.fund_scale.reindex(self.fund_nav.index).fillna(method='ffill').iloc[-1]
+        self.fund_scale['datetime'] = self.fund_nav.index.array[-1]
+        self.fund_scale = self.fund_scale.pivot_table(index='datetime', columns='fund_id', values='latest_size').iloc[0, :]
         # 基金天数
         _get_days = lambda x : pd.Series(x).count()
         self.days = self.fund_nav.count() - 1
@@ -56,7 +54,7 @@ class BasicFundRet(BasicDataPart1):
 
     def get_annual_ret(self):
         '''
-        累积年化收益
+        累计年化收益
         exp(log(p[-1] / p[0]) / (trade_days / 242)) - 1
         '''
         self.log_total_ret = np.log(self.total_ret)
@@ -65,7 +63,7 @@ class BasicFundRet(BasicDataPart1):
 
     def get_annual_vol(self):
         '''
-        累积年化波动率
+        累计年化波动率
         (p.shift(1) / p).std(ddof=1) * np.sqrt((days - 1) / year)
         '''
         diff = self.fund_nav.shift(1) / self.fund_nav
@@ -75,7 +73,7 @@ class BasicFundRet(BasicDataPart1):
 
     def get_mdd(self):
         '''
-        累积最大回撤
+        累计最大回撤
         1 - (p / p.cummax()).min()
         '''
         return 1 - (self.fund_nav / self.fund_nav.cummax()).min()
@@ -98,8 +96,8 @@ class BasicFundRet(BasicDataPart1):
         self.mdd = self.get_mdd()
         self.recent_y_ret = self.fund_nav_fill.iloc[-1] / self.fund_nav_fill.loc[self.begin_day_of_year:].fillna(method = 'bfill').iloc[0] - 1
 
-        data_list = [self.w1_ret, self.m1_ret, self.m3_ret, self.m6_ret, self.y1_ret, self.y3_ret, self.y5_ret, self.to_date_ret, self.fund_scale, self.annual_ret, self.sharpe_ratio, self.mdd, self.recent_y_ret,self.vol]
-        fac_list = ['w1_ret', 'm1_ret', 'm3_ret', 'm6_ret', 'y1_ret', 'y3_ret', 'y5_ret', 'to_date_ret', 'avg_size', 'annual_ret', 'sharpe_ratio', 'mdd', 'recent_y_ret','vol']
+        data_list = [self.w1_ret, self.m1_ret, self.m3_ret, self.m6_ret, self.y1_ret, self.y3_ret, self.y5_ret, self.to_date_ret, self.fund_scale, self.annual_ret, self.sharpe_ratio, self.mdd, self.recent_y_ret, self.vol]
+        fac_list = ['w1_ret', 'm1_ret', 'm3_ret', 'm6_ret', 'y1_ret', 'y3_ret', 'y5_ret', 'to_date_ret', 'avg_size', 'annual_ret', 'sharpe_ratio', 'mdd', 'recent_y_ret', 'vol']
         self.res = []
         for name, data in zip(fac_list, data_list):
             df = pd.DataFrame(data).rename(columns = {0:name,self.fund_nav.index[-1]:'avg_size'})
@@ -112,7 +110,7 @@ class BasicFundRet(BasicDataPart1):
     def process_all(self, end_date):
         failed_tasks = []
         try:
-            default_begin_date = '20050101'#算累积指标用较久对起始日
+            default_begin_date = '20050101'#算累计指标用较久对起始日
             self.init(default_begin_date, end_date)
             self.calculate_one_date()
             self._data_helper._upload_basic(self.result, FundRet.__table__.name)
