@@ -9,9 +9,9 @@ from .derived_data_helper import DerivedDataHelper
 from .fund_indicator_processor_weekly import FundIndicatorProcessorWeekly
 from .fund_indicator_processor_monthly import FundIndicatorProcessorMonthly
 from .derived_index_ret_vol import IndexIndicatorProcessor
+from .derived_fund_aic import AIPProcess
 from ...api.basic import BasicDataApi
 
-
 class DerivedDataProcessor:
     def __init__(self):
         self._data_helper = DerivedDataHelper()
@@ -21,6 +21,7 @@ class DerivedDataProcessor:
         self.fund_score_processor = FundScoreProcessor(self._data_helper)
         self.index_val_processor = IndexValProcess(self._data_helper)
         self.index_indicator = IndexIndicatorProcessor(self._data_helper)
+        self.fund_aip = AIPProcess(self._data_helper)
         self.style_analysis_processors: List[StyleAnalysisProcessor] = []
         # 暂时只算这三个universe
         for universe in ('hs300', 'csi800', 'all'):
@@ -33,6 +34,7 @@ class DerivedDataProcessor:
         failed_tasks.extend(self.fund_score_processor.process(start_date, end_date))
         failed_tasks.extend(self.index_val_processor.process(start_date, end_date))
         failed_tasks.extend(self.index_indicator.process(end_date))
+        failed_tasks.extend(self.fund_aip.process(start_date, end_date))
         for sap in self.style_analysis_processors:
             failed_tasks.extend(sap.process(start_date, end_date))
 
