@@ -19,7 +19,7 @@ class RqRawDataDownloader(object):
         rq.init('license', rq_license, ('rqdatad-pro.ricequant.com', 16011))
 
         # Get all fund order_book_ids
-        self._fund_order_book_id_list = list(set(rq.fund.all_instruments()['order_book_id'].tolist()))
+        # self._fund_order_book_id_list = list(set(rq.fund.all_instruments()['order_book_id'].tolist()))
 
         # Get stock order_book_ids
         # self._stock_order_book_id_list = rq.all_instruments(type='CS', market='cn')['order_book_id'].tolist()
@@ -236,7 +236,9 @@ class RqRawDataDownloader(object):
 
     def fund_rating(self, start_date, end_date):
         try:
-            df = rq.fund.get_ratings(self._fund_order_book_id_list)
+            fund_order_book_id_list = list(set(rq.fund.all_instruments()['order_book_id'].tolist()))
+            df = rq.fund.get_ratings(fund_order_book_id_list)
+            # df = rq.fund.get_ratings(self._fund_order_book_id_list)
             if df is not None:
                 df.reset_index(inplace=True)
                 df = df[(df['datetime'] >= start_date) & (df['datetime'] <= end_date)]
@@ -247,6 +249,19 @@ class RqRawDataDownloader(object):
             traceback.print_exc()
             return False
 
+    def stock_minute(self):
+        try:
+            stock_order_book_id_list = rq.all_instruments(type='CS', market='cn')['order_book_id'].tolist()
+            df = rq.current_minute(stock_order_book_id_list, skip_suspended=True)
+            if df is not None:
+                df.reset_index(inplace=True)
+                self._data_helper._upload_raw(df, RqStockMinute.__table__.name)
+            return df
+        except Exception as e:
+            print(e)
+            traceback.print_exc()
+            return None
+
     def download_all(self, start_date, end_date):
         failed_tasks = []
         # # Safe to disable
@@ -305,6 +320,7 @@ if __name__ == "__main__":
 
     rq_license = SurfingConfigurator().get_license_settings('rq')
     raw_data_downloader = RqRawDataDownloader(rq_license, RawDataHelper())
+    raw_data_downloader.stock_minute()
     # raw_data_downloader.rq_index_price('20200421', '20200422')
     # raw_data_downloader.rq_index_weight('20200428', '20200428')
     # raw_data_downloader.rq_stock_price('20050101', '20091231')
