@@ -4,16 +4,18 @@ import os
 import datetime
 import traceback
 import requests
+import urllib3
 from ...wrapper.mysql import RawDatabaseConnector
 from .raw_data_helper import RawDataHelper
 
+
 class WebRawDataDownloader(object):
-    
+
     def __init__(self, data_helper):
         self._data_helper = data_helper
-    
+
     def read_csv(self, csv_path):
-        return pd.read_csv(csv_path, index_col = 1)
+        return pd.read_csv(csv_path, index_col=1)
 
     def fund_fee(self):
         pass
@@ -22,10 +24,10 @@ class WebRawDataDownloader(object):
         # Update manually
         # Default file in company wechat is 'fundlist_wind_20202015.xlsx'
         df = pd.read_excel(csv_path)
-        df.columns = ['wind_id', 'desc_name', 'full_name', 'start_date', 'end_date', 'benchmark', 'wind_class_1', 
+        df.columns = ['wind_id', 'desc_name', 'full_name', 'start_date', 'end_date', 'benchmark', 'wind_class_1',
             'wind_class_2', 'currency', 'base_fund_id', 'is_structured', 'is_open', 'manager_id', 'company_id']
         df['start_date'] = df['start_date'].map(lambda x: datetime.datetime.strptime(x, '%Y-%m-%d'))
-        df['end_date'] = df['end_date'].map(lambda x: datetime.datetime.strptime(x, '%Y-%m-%d') 
+        df['end_date'] = df['end_date'].map(lambda x: datetime.datetime.strptime(x, '%Y-%m-%d')
             if isinstance(x, str) else datetime.datetime.strptime('2040-12-31', '%Y-%m-%d'))
         df['is_structured'] = df['is_structured'].map(lambda x: False if x == '否' else True)
         df['is_open'] = df['is_open'].map(lambda x: False if x == '否' else True)
@@ -40,7 +42,7 @@ class WebRawDataDownloader(object):
             # df.columns = ['datetime','usd_central_parity_rate','eur_central_parity_rate','jpy_central_parity_rate',
             #               'usd_cfets','eur_cfets','jpy_cfets']
 
-            # auto update 
+            # auto update
             # data from http://www.chinamoney.com.cn/chinese/bkccpr
             start_date = datetime.datetime.strptime(start_date, '%Y%m%d').strftime('%Y-%m-%d')
             end_date = datetime.datetime.strptime(end_date, '%Y%m%d').strftime('%Y-%m-%d')
@@ -48,14 +50,18 @@ class WebRawDataDownloader(object):
                 f'?startDate={start_date}&endDate={end_date}&currency=USD/CNY,EUR/CNY,100JPY/CNY')
             headers = {'User-Agent': ('Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_3) AppleWebKit/605.1.15 '
                                       '(KHTML, like Gecko) Version/13.0.5 Safari/605.1.15')}
-            r = requests.get(url, headers=headers)
-            filename = os.path.join('/tmp', 'cm.xlsx')
-            with open(filename, 'wb') as f:
-                f.write(r.content)
+            filename = ''
+            try:
+                r = requests.get(url, headers=headers)
+                filename = os.path.join('/tmp', 'cm.xlsx')
+                with open(filename, 'wb') as f:
+                    f.write(r.content)
+            except Exception:
+                pass
             df = pd.read_excel(filename)
             # Drop last 2 lines in excel, which are
-            #   数据来源：	中国货币网		
-            #   www.chinamoney.com.cn		
+            #   数据来源：	中国货币网
+            #   www.chinamoney.com.cn
             df.drop(df.index[-2:], inplace=True)
             df = df[['日期', 'USD/CNY', 'EUR/CNY', '100JPY/CNY']]
             df.columns = ['datetime', 'usd_central_parity_rate', 'eur_central_parity_rate', 'jpy_central_parity_rate']
@@ -65,9 +71,9 @@ class WebRawDataDownloader(object):
             return True
         except Exception as e:
             print(e)
-            traceback.print_stack()
+            traceback.print_exc()
             return False
-        
+
     def cxindex_index_price(self, start_date, end_date):
         try:
             # history
@@ -78,16 +84,20 @@ class WebRawDataDownloader(object):
             # df['index_id'] = 'credit_debt'
             # df = df.drop(['symbol'], axis=1)[:-2]
 
-            # auto update 
+            # auto update
             # data from http://www.csindex.com.cn/zh-CN/indices/index-detail/H11073
             # File download url
             url = 'http://www.csindex.com.cn/uploads/file/autofile/perf/H11073perf.xls'
-            r = requests.get(url)
-            filename = os.path.join('/tmp', 'H11073perf.xls')
-            with open(filename, 'wb') as f:
-                f.write(r.content)
+            filename = ''
+            try:
+                r = requests.get(url)
+                filename = os.path.join('/tmp', 'H11073perf.xls')
+                with open(filename, 'wb') as f:
+                    f.write(r.content)
+            except:
+                pass
             df = pd.read_excel(filename)
-            df = df[['日期Date', '收盘Close', '涨跌幅(%)Change(%)', '成交量（万元）Volume(10 thousand CNY)', 
+            df = df[['日期Date', '收盘Close', '涨跌幅(%)Change(%)', '成交量（万元）Volume(10 thousand CNY)',
                 '成交金额（元）Turnover']]
             df.columns = ['datetime', 'close', 'ret', 'volume', 'total_turnover']
             df['volume'] = df['volume'].values * 10000
@@ -101,7 +111,7 @@ class WebRawDataDownloader(object):
             return True
         except Exception as e:
             print(e)
-            traceback.print_stack()
+            traceback.print_exc()
             return False
 
     def yahoo_index_price(self, start_date, end_date):
@@ -121,13 +131,13 @@ class WebRawDataDownloader(object):
             #     df_i['total_turnover'] = float('Nan')
             #     df_i['index_id'] = c
             #     self._data_helper._upload_raw(df_i, 'yahoo_index_price')
-        
-            # auto update 
-            # data from 
+
+            # auto update
+            # data from
             # sp500 https://finance.yahoo.com/quote/%5EGSPC/history?p=%5EGSPC
             # n225 https://finance.yahoo.com/quote/%5EN225/history?p=%5EN225
             # dax30 https://finance.yahoo.com/quote/%5EGDAXI/history/
-            # File download url: 
+            # File download url:
             # https://query1.finance.yahoo.com/v7/finance/download/%5EGSPC?period1=1553667756&period2=1585290156&interval=1d&events=history
             # https://query1.finance.yahoo.com/v7/finance/download/%5EN225?period1=1553673330&period2=1585295730&interval=1d&events=history
             # https://query1.finance.yahoo.com/v7/finance/download/%5EGDAXI?period1=1553673346&period2=1585295746&interval=1d&events=history
@@ -143,10 +153,14 @@ class WebRawDataDownloader(object):
             df_list = []
             for url_type, csv_i, index_i in zip(url_type_list, csv_list, index_list):
                 url = url_prefix + url_type + url_postfix
-                r = requests.get(url)
-                filename = os.path.join('/tmp', csv_i)
-                with open(filename, 'wb') as f:
-                    f.write(r.content)
+                filename = ''
+                try:
+                    r = requests.get(url)
+                    filename = os.path.join('/tmp', csv_i)
+                    with open(filename, 'wb') as f:
+                        f.write(r.content)
+                except Exception:
+                    pass
                 df = pd.read_csv(filename)
                 df = df[['Date', 'Open', 'High', 'Low', 'Close', 'Adj Close', 'Volume']]
                 df.columns = ['datetime', 'open', 'high', 'low', 'close', 'adjclose', 'volume']
@@ -154,8 +168,8 @@ class WebRawDataDownloader(object):
                 df['index_id'] = index_i
                 df['total_turnover'] = float('Nan')
                 df['ret'] = df['adjclose'] / df['adjclose'].shift(1) - 1
-                df = df.drop(['adjclose'], axis = 1)
-                df = df[(df['datetime']>=start_date) & (df['datetime']<=end_date)].sort_values('datetime')
+                df = df.drop(['adjclose'], axis=1)
+                df = df[(df['datetime'] >= start_date) & (df['datetime'] <= end_date)].sort_values('datetime')
                 if not df.empty:
                     df_list.append(df)
             if df_list:
@@ -164,7 +178,7 @@ class WebRawDataDownloader(object):
             return True
         except Exception as e:
             print(e)
-            traceback.print_stack()
+            traceback.print_exc()
             return False
 
     def download_all(self, start_date, end_date):
@@ -179,8 +193,10 @@ class WebRawDataDownloader(object):
             failed_tasks.append('yahoo_index_price')
 
         return failed_tasks
-        
+
+
 if __name__ == "__main__":
     data_helper = RawDataHelper()
     web_downloader = WebRawDataDownloader(data_helper)
-    web_downloader.cm_index_price('20200408', '20200508')
+    # web_downloader.cm_index_price('20200408', '20200508')
+    # web_downloader.yahoo_index_price('20200427', '20200710')
