@@ -18,6 +18,10 @@ BLACK_SHEEP.extend(['000512!0'])
 ## ‘001879!0’: '长城创业板指数增强A'   曾用名 长城创新动力灵活配置混合基金
 BLACK_SHEEP.extend(['001879!0'])
 
+#基金类别改变 2020-07-27
+## ’519034!0' "海富通中证500增强" 曾用名 海富通中证低碳
+BLACK_SHEEP.extend(['519034!0'])
+
 # 发生净值突变的分级基金 属于放宽国债tag，加入信用债下的基金  2020-06-22
 ## 向上波动 '164210!1': 天弘同利分级, '164703!1': 汇添富互利分级 ,
 ## 向下波动 '000428!0' : 易方达聚盈分级
