@@ -1,5 +1,5 @@
 
-from typing import Dict, Any, Set
+from typing import Dict, Any, Set, Optional, Union
 from collections import defaultdict
 from ..struct import FundScoreParam, ScoreFilter, ScorePenaltyParams
 from .data_tables import FundDataTables
@@ -153,7 +153,7 @@ class FundScoreManager:
         self.funcs = {
             'hs300': ScoreFunc(alpha=0.6/ 0.0444, beta=-0.3, track_err=-0.0/0.03939 ,fee_rate=-0.0/ 0.00266),
             'csi500': ScoreFunc(alpha=0.9/ 0.08291, beta=-0.1),
-            'gem':ScoreFunc(alpha=0.45/0.04332, beta=-0.40, track_err=-0.15/0.04749),
+            'gem':ScoreFunc(alpha=0.3/0.04332, beta=-0.50, track_err=-0.2/0.04749),
             'national_debt': ScoreFunc(alpha=0.3/0.08303, beta=-0.5, track_err=-0.4/0.05373, fee_rate=-0.0/0.00229),
             'mmf': ScoreFunc(alpha=0.3/0.00917, beta=-0.2, fee_rate=-0.1/0.00084, track_err=-0.4/0.00123),
             'sp500rmb': ScoreFunc(fee_rate=-0.2/0.00228, track_err=-0.8/0.01088),
@@ -174,19 +174,50 @@ class FundScoreManager:
         self.fund_id_to_name = self.dts.fund_info[['fund_id', 'desc_name']].set_index('fund_id').to_dict()['desc_name']
         self.fund_name_to_id = self.dts.fund_info[['fund_id', 'desc_name']].set_index('desc_name').to_dict()['fund_id']
 
-    def get_fund_score(self, dt, index_id, is_filter_c, fund_score_funcs=None) -> dict:
+    def _get_fund_score(self, dt, index_id, is_filter_c, score_func: Optional[ScoreFunc] = None) -> dict:
         assert self.params and self.dts, 'cannot provide fund_score without params or data tables'
-        score, score_raw = self._get_score(index_id=index_id, dt=dt, cur_d=self.dts.index_fund_indicator_pack.loc[index_id, dt], is_filter_c=is_filter_c, fund_score_funcs=fund_score_funcs)
-        return score, score_raw
+        try:
+            # pivot_table会把index以外各列都为nan的行自动干掉(感觉应该是bug，而且dropna=False的行为也不合理)
+            # 因此这里如果找不到的话直接返回空
+            cur_d = self.dts.index_fund_indicator_pack.loc[index_id, dt]
+        except KeyError:
+            return {}, {}
+        return self._get_score(index_id=index_id, dt=dt, cur_d=cur_d, is_filter_c=is_filter_c, score_func=score_func)
 
-    def get_fund_scores(self, dt, index_list, is_filter_c=True, fund_score_funcs=None) -> dict:
-        if not self.score_cache or fund_score_funcs:
-            score = {}
-            score_raw = {}
+    def get_fund_score(self, dt, index_id, is_filter_c, score_func: Optional[Union[ScoreFunc, str]] = None):
+        if score_func is not None and score_func:
+            # 指定了score_func，缓存里肯定没有，直接算一遍然后返回
+            return self._get_fund_score(dt, index_id, is_filter_c, score_func)
+        try:
+            # 先尝试从缓存里取
+            return self.score_cache[dt][index_id], self.score_raw_cache[dt][index_id]
+        except KeyError:
+            # 获取不到的话则算一遍，注意这里不存缓存
+            return self._get_fund_score(dt, index_id, is_filter_c)
+
+    def get_fund_scores(self, dt, index_list, is_filter_c=True, fund_score_funcs: Optional[Dict[str, Union[ScoreFunc, str]]] = None) -> dict:
+        index_score = self.score_cache[dt]
+        index_score_raw = self.score_raw_cache[dt]
+        if not index_score or not index_score_raw:
+            # 先用默认的fund_score_funcs对所有的index算一下
             for index_id in index_list:
-                score[index_id], score_raw[index_id] = self.get_fund_score(dt, index_id, is_filter_c, fund_score_funcs)
-            return score, score_raw
-        return self.score_cache.get(dt, {}), self.score_raw_cache.get(dt, {})
+                # 这里由于index_score和index_score_raw都是dict, 所以我们这样赋值可以更新到self.score_cache和self.score_raw_cache
+                index_score[index_id], index_score_raw[index_id] = self._get_fund_score(dt, index_id, is_filter_c)
+
+        # 没有指定fund_score_funcs，可以直接返回
+        if fund_score_funcs is None or not fund_score_funcs:
+            return index_score, index_score_raw
+
+        # 如果指定了fund_score_funcs，需要重新算一下其中指定的index
+        score = {}
+        score_raw = {}
+        for index_id, func in fund_score_funcs.items():
+            score[index_id], score_raw[index_id] = self._get_fund_score(dt, index_id, is_filter_c, func)
+        # 将指定的index的和默认的index组合到一起返回
+        # python3.9可以直接用"|"运算符
+        score.update({index_id: v for index_id, v in index_score.items() if index_id not in score})
+        score_raw.update({index_id: v for index_id, v in index_score_raw.items() if index_id not in score_raw})
+        return score, score_raw
 
     def _wrapper(self, df: pd.DataFrame, is_filter_c: bool, use_weekly_monthly_indicators: bool):
         # T日大类下有很多基金，这里取一下它们的datetime和index_id，因为值都是一样的所以取array[0]就OK
@@ -203,18 +234,28 @@ class FundScoreManager:
         # 这里应该没必要先groupby datetime，再groupby index_id（如果真这样可能更慢吧）
         self.dts.fund_indicator.groupby(by=['datetime', 'index_id']).apply(lambda x: self._wrapper(x, is_filter_c, use_weekly_monthly_indicators))
 
-    def _get_score(self, index_id, dt, cur_d, is_filter_c,use_weekly_monthly_indicators=False,fund_score_funcs=None) :
+    def _get_score(self, index_id, dt, cur_d, is_filter_c, use_weekly_monthly_indicators=False, score_func: Optional[Union[ScoreFunc, str]] = None):
         fund_ids = self._filter_size_and_com_hold(dt, index_id, cur_d.index)
         if fund_ids is not cur_d.index:
             # 这里没有dropna总计可以快24秒
             cur_d = cur_d.reindex(fund_ids)
         if cur_d.shape[0] > 1:
             # 不做归一化
-            func = self.funcs.get(index_id) if fund_score_funcs is None or fund_score_funcs.get(index_id) is None else fund_score_funcs.get(index_id)
-            if use_weekly_monthly_indicators:
-                score_raw = cur_d.apply(lambda x: func.get_all(x), axis=1)
+            func = self.funcs.get(index_id) if score_func is None else score_func
+            if isinstance(func, str):
+                try:
+                    FundScoreManager.test_func(func)
+                except Exception as e:
+                    # func str不合法，直接返回空
+                    print(f'eval fund score func str failed for {index_id} (err_msg){e}')
+                    return {}, {}
+                score_raw = cur_d.apply(FundScoreManager.get_func(func), axis=1)
             else:
-                score_raw = cur_d.apply(lambda x: func.get(x), axis=1)
+                # 默认均走这个分支
+                if use_weekly_monthly_indicators:
+                    score_raw = cur_d.apply(lambda x: func.get_all(x), axis=1)
+                else:
+                    score_raw = cur_d.apply(lambda x: func.get(x), axis=1)
 
             if index_id in self.score_penalty_param.FilterYearIndex:
                 punish_funds = cur_d[cur_d.year_length < self.score_penalty_param.JudgeYearLength].index.tolist()
