@@ -189,6 +189,22 @@ class FundNav(Base):
     )
 
 
+class FundEstimatedNav(Base):
+    '''基金估算净值表'''
+
+    __tablename__ = 'fund_estimated_nav'
+    fund_id = Column(CHAR(20), primary_key=True) # 合约代码
+    datetime = Column(DATETIME, primary_key=True) # 估算时间
+
+    unit_net_value = Column(DOUBLE(asdecimal=False)) # 单位净值
+    acc_net_value = Column(DOUBLE(asdecimal=False)) # 累计单位净值 基金公司公告发布的原始数据 单位净值 + 单位累计分红
+    adjusted_net_value = Column(DOUBLE(asdecimal=False)) # 复权净值 考虑分红再投资后调整的单位净值
+
+    __table_args__ = (
+        Index('idx_fund_estimated_nav_datetime', 'datetime'),
+    )
+
+
 class IndexPrice(Base):
     '''指数价格表'''
 
