@@ -82,6 +82,26 @@ class RqStockPostPrice(Base):
     )
 
 
+class RqStockMinute(Base):
+    '''米筐股票分钟线数据表'''
+
+    __tablename__ = 'rq_stock_minute'
+
+    order_book_id = Column(CHAR(20), primary_key=True) # 股票ID
+    datetime = Column(DATETIME, primary_key=True) # 日期
+
+    open = Column(DOUBLE(asdecimal=False)) # 开盘价
+    close = Column(DOUBLE(asdecimal=False)) # 收盘价
+    high = Column(DOUBLE(asdecimal=False)) # 最高价
+    low = Column(DOUBLE(asdecimal=False)) # 最低价
+    total_turnover = Column(DOUBLE(asdecimal=False)) # 成交额
+    volume = Column(DOUBLE(asdecimal=False)) # 成交量  不复权和后复权的交易量不同
+
+    __table_args__ = (
+        Index('idx_rq_stock_minute_datetime', 'datetime'),
+    )
+
+
 class RqFundNav(Base):
     '''米筐基金净值表'''
 
