@@ -1,4 +1,4 @@
-from sqlalchemy import CHAR, Column, DATE, text, TEXT
+from sqlalchemy import CHAR, Column, DATE, text, TEXT, Integer
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.dialects.mysql import DOUBLE, DATETIME
 
@@ -31,7 +31,7 @@ class FundDailyCollection(Base):
     track_index = Column(CHAR(20)) # 跟踪指数
 
     unit_net_value = Column(DOUBLE(asdecimal=False))  # 单位净值
-    acc_net_value = Column(DOUBLE(asdecimal=False))  # 累积单位净值
+    acc_net_value = Column(DOUBLE(asdecimal=False))  # 累计单位净值
     adjusted_net_value = Column(DOUBLE(asdecimal=False))  # 复权净值
     change_rate = Column(DOUBLE(asdecimal=False))  # 日收益率
     found_date = Column(CHAR(20))  # 成立日期
@@ -51,6 +51,17 @@ class FundDailyCollection(Base):
     y5_ret = Column(DOUBLE(asdecimal=False))  # 近五年收益率
     vol = Column(DOUBLE(asdecimal=False))  # 波动率（成立以来）
 
+    last_week_return_rank = Column(Integer)  # 近一周同类排名
+    last_month_return_rank = Column(Integer)  # 近一月同类排名
+    last_three_month_return_rank = Column(Integer)  # 近三月同类排名
+    last_six_month_return_rank = Column(Integer)  # 近六月同类排名
+    last_twelve_month_return_rank = Column(Integer)  # 近一年同类排名
+    y3_ret_rank = Column(Integer)  # 近三年同类排名
+    y5_ret_rank = Column(Integer)  # 近五年同类排名
+    year_to_date_return_rank = Column(Integer)  # 年初至今同类排名
+    to_date_return_rank = Column(Integer)  # 成立以来同类排名
+    group_num = Column(Integer)  # 同类数量
+
     fund_manager = Column(CHAR(255))  # 基金经理
     company_name = Column(CHAR(64))  # 基金公司
     symbol = Column(CHAR(64)) # 基金名称
@@ -117,7 +128,7 @@ class FundDailyCollection(Base):
             'theme': '基金主题',
             'adjusted_net_value': '复权净值',
             'unit_net_value': '净值',
-            'acc_net_value': '累积净值',
+            'acc_net_value': '累计净值',
             'change_rate': '日收益率',
             'found_date': '成立日期',
             'annualized_returns': '年化收益',
@@ -141,6 +152,17 @@ class FundDailyCollection(Base):
             'benchmark_s': '跟踪标的ID',
             'benchmark_name': '跟踪标的',
 
+            'last_week_return_rank': '近一周同类排名',
+            'last_month_return_rank': '近一月同类排名',
+            'last_three_month_return_rank': '近三月同类排名',
+            'last_six_month_return_rank': '近六月同类排名',
+            'last_twelve_month_return_rank': '近一年同类排名',
+            'y3_ret_rank': '近三年同类排名',
+            'y5_ret_rank': '近五年同类排名',
+            'year_to_date_return_rank': '年初至今同类排名',
+            'to_date_return_rank': '成立以来同类排名',
+            'group_num': '同类数量',
+
             'zs': '招商评级',
             'sh3': '上证三年评级',
             'sh5': '上证五年评级',
@@ -151,7 +173,7 @@ class FundDailyCollection(Base):
             'track_err': '跟踪误差',
             'this_y_alpha': '今年以来超额收益',
             'cumulative_alpha': '成立以来超额收益',
-            'w1_alpha': '近一周收益率',
+            'w1_alpha': '近一周超额收益',
             'm1_alpha': '近一月超额收益',
             'm3_alpha': '近三月超额收益',
             'm6_alpha': '近半年超额收益',
@@ -239,6 +261,7 @@ class IndexDailyCollection(Base):
     industry_tag = Column(CHAR(64))  # 行业标签
     tag_method = Column(CHAR(64))  # 估值评分采用方法
     desc_name = Column(CHAR(64))  # 名称
+    id_cat = Column(CHAR(64), nullable=False)  # 所属类型
 
     @staticmethod
     def trans_columns():
@@ -293,6 +316,7 @@ class IndexDailyCollection(Base):
             'industry_tag': '行业标签',
             'tag_method': '估值评分采用方法',
             'desc_name': '指数名称',
+            'id_cat': '所属类型',
         }
 
 
