@@ -1,3 +1,5 @@
+
+from typing import Dict, Union, Optional
 import datetime
 import copy
 import json
@@ -10,7 +12,7 @@ from .asset_helper import SAAHelper, TAAHelper, FAHelper
 from .trader import AssetTrader, FundTrader
 from .report import ReportHelper
 from ...data.manager.manager_fund import FundDataManager
-from ...data.manager.score import ScoreFunc
+from ...data.manager.score import ScoreFunc, FundScoreManager
 from ...data.struct import AssetWeight, AssetPrice, AssetPosition, AssetValue
 from ...data.struct import FundPosition, TAAParam, AssetTradeParam, FundTradeParam, FAParam
 from ...util.calculator import Calculator
@@ -19,7 +21,7 @@ class FundEngine:
 
     DEFAULT_CASH_VALUE = 1e8
 
-    def __init__(self, data_manager: FundDataManager, trader, taa_params:TAAParam=None, fa_params:FAParam=None, taa_param_details:dict=None, is_old_version=False, white_list:set=None, black_list:set=None, fund_score_funcs=None):
+    def __init__(self, data_manager: FundDataManager, trader, taa_params:TAAParam=None, fa_params:FAParam=None, taa_param_details:dict=None, is_old_version=False, white_list:set=None, black_list:set=None, fund_score_funcs: Optional[Dict[str, Union[ScoreFunc, str]]] = None):
         self._dm = data_manager
         self._saa_helper = SAAHelper()
         self._taa_helper = TAAHelper(taa_params=taa_params, taa_param_details=taa_param_details) if taa_params or taa_param_details else None 
@@ -27,7 +29,12 @@ class FundEngine:
         self._report_helper = ReportHelper()
         self._trader = trader
         self._is_old_version = is_old_version
-        self._fund_score_funcs = fund_score_funcs
+        self._fund_score_funcs: Union[Dict[str, ScoreFunc], str] = fund_score_funcs
+        if self._fund_score_funcs is not None:
+            for index_id, func in self._fund_score_funcs.items():
+                if isinstance(func, str):
+                    print(f'check score func "{func}" for {index_id}')
+                    FundScoreManager.test_func(func)
         self._pending_trades = []
         # 黑白名单和全部基金列表处理 得到不允许交易基金列表， 对其中基金评分惩罚
         self.white_list = white_list
@@ -420,7 +427,7 @@ def qieman_backtest(m: FundDataManager, saa:AssetWeight):
     bk_result = bk.get_fund_result()
     return bk_result
 
-def change_score_function(m: FundDataManager, saa:AssetWeight):
+def change_score_function(m: FundDataManager, saa: AssetWeight):
     t = FundTrader(AssetTradeParam(), FundTradeParam())
     taa_param = TAAParam()
     fa_param = FAParam()
@@ -428,12 +435,20 @@ def change_score_function(m: FundDataManager, saa:AssetWeight):
         'hs300': ScoreFunc(alpha=0, beta=-1, fee_rate=0),
         'csi500': ScoreFunc(alpha=0, beta=-1)
     }
-    end_date = datetime.date.today()
-    #end_date = datetime.date(2020,7,8)
-    begin_date = datetime.date(2012,1,1)
     bk = FundBacktestEngine(data_manager=m, trader=t, taa_params=taa_param, fa_params=fa_param, fund_score_funcs=funcs)
     bk.init()
-    bk.run(saa=saa, start_date=begin_date, end_date=end_date)
+    bk.run(saa=saa)
+    bk_result = bk.get_fund_result()
+    return bk_result
+
+def change_formula_score_function(m: FundDataManager, saa: AssetWeight):
+    t = FundTrader(AssetTradeParam(), FundTradeParam())
+    taa_param = TAAParam()
+    fa_param = FAParam()
+    func_str = '0.5 * alpha + 0.1 * abs(1 - beta)'
+    bk = FundBacktestEngine(data_manager=m, trader=t, taa_params=taa_param, fa_params=fa_param, fund_score_funcs={'hs300': func_str})
+    bk.init()
+    bk.run(saa=saa)
     bk_result = bk.get_fund_result()
     return bk_result
 
@@ -452,11 +467,13 @@ def test():
         cash=5/100
     )
     
-    #saa_backtest(m, saa)
-    #taa_backtest(m, saa)
-    #fund_backtest_without_taa(m, saa)
+    # saa_backtest(m, saa)
+    # taa_backtest(m, saa)
+    # fund_backtest_without_taa(m, saa)
     fund_backtest(m, saa)
-    #fund_realtime(m, saa)
+    # fund_realtime(m, saa)
+    # change_score_function(m, saa)
+    # change_formula_score_function(m, saa)
 
 if __name__ == '__main__':
     # profile(file_name='/Users/cjiang/taa_perf1.txt', func=fund_backtest)
