@@ -3,6 +3,7 @@ import numpy as np
 import platform
 import matplotlib as mpl
 import pylab as pl
+import datetime
 import matplotlib.pyplot as plt
 import matplotlib.cm as cm
 import matplotlib.colors as colors
@@ -243,4 +244,88 @@ class HybridPainter(object):
         plt.legend(loc='upper left', fontsize=15)
         plt.grid()
         plt.show()
-        return stats
\ No newline at end of file
+        return stats
+
+    @staticmethod
+    def regular_rebalance_in_index_strategy(begin_date:datetime.date,
+                                            end_date:datetime.date,
+                                            index_id:str,
+                                            rebalance_year:float,
+                                            top_funds:int,
+                                            dts:pd.Series,
+                                            fund_score_dic:dict,
+                                            fund_info:pd.DataFrame,
+                                            index_price:pd.DataFrame,
+                                            fund_nav:pd.DataFrame):
+        
+        def _get_top_funds(fund_score_dic, index_id, dt, top_nums):
+            _score_dict = fund_score_dic[dt][index_id]
+            _score_list = sorted(_score_dict.items(), key=lambda x:x[1], reverse=True)
+            _fund_list = [i[0] for i in _score_list]
+            if top_nums > len(_fund_list):
+                return _fund_list
+            else:
+                return _fund_list[:top_nums]
+
+        rebalance_date = int(rebalance_year * 242)
+        fund_info['trade_fee'] = 0.15 * fund_info['purchase_fee'] + fund_info['redeem_fee']
+        fee_df = fund_info[['fund_id','trade_fee']].set_index('fund_id')
+        desc_name = fund_info[['fund_id','desc_name']].set_index('fund_id').to_dict()['desc_name']
+
+        _dts = dts[(dts >= begin_date) & (dts <= end_date )].tolist()
+        res = []
+        for _idx, _dt in enumerate(_dts):
+            if _idx % rebalance_date == 0:
+                dic = {
+                    'start_date':_dt,
+                    'fund_list':_get_top_funds(fund_score_dic, index_id, _dt, top_funds),
+                }
+            elif _idx % rebalance_date == (rebalance_date-1):
+                dic['end_date'] = _dt
+                res.append(dic)
+                dic = {
+                    'start_date':_dt,
+                    'fund_list':_get_top_funds(fund_score_dic, index_id, _dt, top_funds),
+                }
+        dic['end_date'] = _dt
+        res.append(dic)
+        _res = []
+        for date_dic in res:
+            fund_nav_i = fund_nav.loc[date_dic['start_date']:date_dic['end_date'],date_dic['fund_list']]
+            for fund_id in fund_nav_i:
+                fund_i_fee = fee_df.loc[fund_id,'trade_fee']
+                fee_discount_l = np.linspace(1,1-fund_i_fee,fund_nav_i.shape[0])
+                fund_nav_i[fund_id] = fund_nav_i[fund_id] * fee_discount_l
+            fund_ret_combine = pd.DataFrame(fund_nav_i.pct_change(1).mean(axis=1).dropna())
+            _res.append(fund_ret_combine)
+        fund_combine_rets = pd.concat(_res).rename(columns={0:'funds'})
+        fund_df = (fund_combine_rets+1).cumprod()
+        fund_df.loc[_dts[0],'funds'] = 1
+        fund_df = fund_df.sort_index()
+        fund_df = fund_df.join(index_price[[index_id]]).fillna(method='ffill')
+        fund_df = fund_df/fund_df.iloc[0]
+        fund_df['price_ratio'] = fund_df['funds'] / fund_df[f'{index_id}']
+        fund_df.plot.line(figsize=(15,8))
+        plt.title(f'Selects top {top_funds} funds and rebalance every {rebalance_year} year in {index_id}',fontsize=25)
+        plt.legend(loc='upper left', fontsize=15)
+        plt.grid()
+        plt.show()
+        stats = Calculator.get_stat_result_from_df(df=fund_df.reset_index(), date_column='datetime', value_column='funds').__dict__
+        result_df = pd.DataFrame([stats])[['annualized_ret','annualized_vol','mdd','sharpe','mdd_date1','mdd_date2']]
+        result_df.index = ['portfolio result']
+        _res = []
+        for dic in res:
+            _dic = {
+                'start_date': dic['start_date'],
+                'end_date':dic['end_date'],
+            }
+            for idx, _fund_id in enumerate(dic['fund_list']):
+                _dic[f'fund_{idx+1}'] = desc_name[_fund_id]
+            _res.append(_dic)
+        pos_df = pd.DataFrame(_res)
+        _col_list = pos_df.columns.tolist()
+        _col_list1 = ['start_date','end_date']
+        _col_list2 = [_ for _ in _col_list if _ not in _col_list1]
+        col_list = _col_list1 + _col_list2
+        pos_df = pos_df[col_list]
+        return result_df, pos_df
\ No newline at end of file
