@@ -283,9 +283,22 @@ class ReportHelper:
             self.index_fee['fee_ratio_avg'] = self.index_fee.commission / self.index_fee.amount
 
     def get_rebalance_detail(self):
-        rebalance_details = [i['rebalance_reason'][0]['rebalanace_reason'] for i in self._rebalance_details]
-        rebalance_details = dict(Counter(rebalance_details))
-        return rebalance_details
+        #rebalance_details = [i['rebalance_reason'][0]['rebalanace_reason'] for i in self._rebalance_details]
+        #rebalance_details = dict(Counter(rebalance_details))
+        trade_df = self.trade_df.copy()
+        fund_mv = self.fund_mv.copy()
+        result = self._calc_stat(fund_mv).copy()
+        _rb_df = pd.DataFrame(self._rebalance_details)
+        submit_date_to_trade_day = trade_df[['submit_date','trade_date']].set_index('submit_date').to_dict()['trade_date']
+        turnover_df = trade_df.groupby('trade_date').sum()[['amount']].join(fund_mv).copy()
+        _rb_df['trade_date'] = _rb_df['datetime'].map(lambda x : submit_date_to_trade_day[x])
+        _rb_df['rebalance reason'] = _rb_df['rebalance_reason'].map(lambda x : x[0]['rebalanace_reason'])
+        _rb_df = _rb_df[['trade_date','rebalance reason']].set_index('trade_date').copy()
+        turnover_df['turnover'] = turnover_df['amount'] / turnover_df['mv'] / 2
+        _df = pd.DataFrame([{'trade_date':d,'hold_year':l} for d,l in result['hold_years'].items()]).set_index('trade_date')
+        _df.index = pd.to_datetime(_df.index)
+        turnover_df = turnover_df.join(_df).join(_rb_df).copy()
+        return turnover_df[['turnover','hold_year','rebalance reason']]
 
     def backtest_asset_plot(self):
         bt_type = 'asset'
@@ -504,4 +517,13 @@ class ReportHelper:
         mv_df = mv_df / mv_df.shift(1)
         annual_ret = (mv_df.rolling(window=242*rolling_year).agg(lambda x : x.prod() - 1))/rolling_year
         FundPainter.plot_rolling_analysis(annual_ret,fund_annual_ret,rolling_year,index_id)
-    
\ No newline at end of file
+    
+    @staticmethod
+    def regular_rebalance_in_index_strategy(m, begin_date,end_date,index_id,rebalance_year,top_funds):
+        dts = m.dts.trading_days.datetime
+        fund_score_dic = m._score_manager.score_cache
+        fund_info = m.dts.fund_info
+        index_price = m.dts.index_price
+        fund_nav = m.dts.fund_nav
+        result_df, pos_df = HybridPainter.regular_rebalance_in_index_strategy(begin_date,end_date,index_id,rebalance_year,top_funds,dts,fund_score_dic,fund_info,index_price,fund_nav)
+        return result_df, pos_df
\ No newline at end of file
