@@ -54,9 +54,9 @@ class AIPCalculator(object):
         if strategy:
             if strategy.startswith('ma'):
                 window_size = int(strategy[2:])
-                self.moving_average = self.arr.rolling(window_size).mean()
-                self.vol_10 = self.arr.rolling(10).std()
-
+                self.moving_average = self.arr.rolling(window_size).mean().fillna(0)
+                self.vol_10 = self.arr.pct_change(1).rolling(10).std().fillna(0)
+                
     def get_yearly_multiplier(self, mode):
         m = None
         if mode == '1d':
@@ -92,6 +92,8 @@ class AIPCalculator(object):
         return pow(ret + 1, 365 / days) - 1
 
     def _mv_multiplier(self, val, ma, vol_10):
+        if ma == 0:
+            return 1
         diff = (val - ma) / ma
         if diff > 0:
             if diff <= 0.15:
@@ -200,9 +202,8 @@ class AIPCalculator(object):
             cur_date += datetime.timedelta(days=1)
 
         # stat
-        self.irr_helper[0].append(-1 * self.cur_mv[-1])
+        self.irr_helper[0].append(-1 * (self.cur_mv[-1] + amt_to_trade)) #如果终止定投前，到了月初投入一笔前，但是一直没到交易日，没有买入资产，这笔前进入了irr_helper，但是没有进入 资产里。终止定投取钱，会少最后一笔
         self.irr_helper[1].append(self.end_date)
-
         self.irr = xirr(self.irr_helper[0], self.irr_helper[1])
         self.tot_mv = self.cur_mv[-1] + sum(self.redeem_amt)
         self.tot_ret = (self.tot_mv) / sum(self.tot_inv_amt) - 1
@@ -263,11 +264,29 @@ class AIPCalculator(object):
             cur_date += datetime.timedelta(days=1)
 
         # stat
-        self.irr_helper[0].append(-1 * self.cur_mv)
+        self.irr_helper[0].append(-1 * (self.cur_mv + amt_to_trade))
         self.irr_helper[1].append(self.end_date)
         self.irr = xirr(self.irr_helper[0], self.irr_helper[1])
         return self.irr
 
+    def get_aip_total_return(self):
+        cash_flow = self.irr_helper[0]
+        cash_inputs = [i for i in cash_flow if i > 0]
+        cash_outputs = [i for i in cash_flow if i < 0]
+        return (-sum(cash_outputs) / sum(cash_inputs)) - 1
+
+    def get_fund_ret(self):
+        _arr = self.arr[self.start_date:self.end_date]
+        return _arr[-1] / _arr[0] - 1
+
+    def get_fund_vol(self):
+        _arr = self.arr[self.start_date:self.end_date]
+        return _arr.pct_change(1).std(ddof=1)
+
+    def get_cash_flow(self):
+        dic = {'datetime':self.irr_helper[1], 'cash_flow':self.irr_helper[0]}
+        return pd.DataFrame(dic)
+
     def plot(self):
         df_net_arr = pd.DataFrame(self.res).set_index('dt')[['p', 'avg_cost']]
         df_net_arr.plot.line(figsize=(12,6))
