@@ -298,7 +298,7 @@ class Calculator:
         pct = getattr(x, val_dict[x.tag_method])
         pe = x.pe_ttm
         if None in [pct,pe]:
-            res = None
+            return None
         if pct < 0.3 and pe < 20:
             res = 'low'
         elif pct > 0.7 and pe > 20:
