@@ -1,15 +1,17 @@
-import datetime
+
+from typing import Dict
 import requests
 import json
-import time
 from .config import SurfingConfigurator
 
+
 class WechatBot(object):
 
     def __init__(self):
         self.wechat_webhook = SurfingConfigurator().get_wechat_webhook_settings('wechat_webhook')
 
     def send(self, markdown_content):
+        print(markdown_content)
         # Send markdown content
         message = {
             'msgtype': 'markdown',
@@ -35,5 +37,19 @@ class WechatBot(object):
             for item, count in item_count.items():
                 markdown_content += f'\n>{key}.{item}: <font color=\"info\">{count}</font>'
 
-        print(markdown_content)
         return self.send(markdown_content)
+
+    def send_new_fund_list(self, dt, new_funds: Dict[str, str], new_delisted_funds: Dict[str, str]):
+        markdown_content = f'#### {dt}'
+        if new_funds is None or new_delisted_funds is None:
+            markdown_content += f' **<font color=\"warning\">获取今日新基金或摘牌基金列表失败</font>**'
+        else:
+            if new_funds:
+                markdown_content += f'\n>新基金({len(new_funds)}): <font color=\"info\">{new_funds}</font>'
+            else:
+                markdown_content += f'\n>无新基金'
+            if new_delisted_funds:
+                markdown_content += f'\n\n>摘牌基金({len(new_delisted_funds)}): <font color=\"info\">{new_delisted_funds}</font>'
+            else:
+                markdown_content += f'\n\n>无摘牌基金'
+        self.send(markdown_content)
